summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
author Eric Hameleers <alien@slackware.com>2016-03-15 15:35:49 +0100
committer Eric Hameleers <alien@slackware.com>2016-03-15 15:35:49 +0100
commit1e4750ef070a6349222d256bde728281033ce1ff (patch)
treeee04a49eb2486aeb041d49ba146d3740531ec1af
parent825607fb5019158f56aab8bb87575baf637aeb26 (diff)
downloadliveslak-1e4750ef070a6349222d256bde728281033ce1ff.tar.gz
liveslak-1e4750ef070a6349222d256bde728281033ce1ff.tar.xz
Further expand the use of DISTRO variable to customize the Live ISO.
-rw-r--r--grub.tpl2
-rwxr-xr-xmake_slackware_live.sh21
-rw-r--r--menu.tpl4
-rwxr-xr-xsetup2hd28
4 files changed, 35 insertions, 20 deletions
diff --git a/grub.tpl b/grub.tpl
index 7ab2dba..65bca62 100644
--- a/grub.tpl
+++ b/grub.tpl
@@ -43,7 +43,7 @@ if loadfont $grubdir/theme/dejavusansmono12.pf2 ; then
export theme
fi
-menuentry "Start Slackware@DIRSUFFIX@ @SL_VERSION@ @LIVEDE@ Live @VERSION@ ($sl_lang)" --hotkey b {
+menuentry "Start @CDISTRO@@DIRSUFFIX@ @SL_VERSION@ @LIVEDE@ Live @VERSION@ ($sl_lang)" --hotkey b {
linux ($root)/boot/generic load_ramdisk=1 prompt_ramdisk=0 rw printk.time=0 kbd=$sl_kbd tz=$sl_tz locale=$sl_locale xkb=$sl_xkb
initrd ($root)/boot/initrd.img
}
diff --git a/menu.tpl b/menu.tpl
index 7f88fb3..e7c051b 100644
--- a/menu.tpl
+++ b/menu.tpl
@@ -4,7 +4,7 @@ ui vesamenu.c32
default live
font @CONSFONT@
menu background swlogov.png
-menu title Slackware@DIRSUFFIX@-@SL_VERSION@ Live @VERSION@
+menu title @CDISTRO@@DIRSUFFIX@-@SL_VERSION@ Live @VERSION@
menu clear
f2 f2.txt #00000000
f3 f3.txt #00000000
@@ -45,7 +45,7 @@ label live
kernel /boot/generic
append initrd=/boot/initrd.img load_ramdisk=1 prompt_ramdisk=0 rw printk.time=0 kbd=@KBD@
text help
- Slackware@DIRSUFFIX@-@SL_VERSION@, kernel @KVER@.
+ @CDISTRO@@DIRSUFFIX@-@SL_VERSION@, kernel @KVER@.
Add 'load=nvidia' to the commandline
if you have a recent NVIDIA card.
endtext
diff --git a/setup2hd b/setup2hd
index ee0b655..0d9b319 100755
--- a/setup2hd
+++ b/setup2hd
@@ -103,18 +103,18 @@ mkdir /var/log/mount 2> /dev/null
while [ 0 ]; do
- dialog --title "Slackware Linux Setup (version current)" \
+ dialog --title "@CDISTRO@ Linux Setup (version @SL_VERSION@)" \
--menu \
-"Welcome to Slackware Linux Setup (Live Edition).\n\
+"Welcome to @CDISTRO@ Linux Setup (Live Edition).\n\
Select an option below using the UP/DOWN keys and SPACE or ENTER.\n\
Alternate keys may also be used: '+', '-', and TAB." 18 72 9 \
-"HELP" "Read the Slackware Setup HELP file" \
+"HELP" "Read the @CDISTRO@ Setup HELP file" \
"KEYMAP" "Remap your keyboard if you're not using a US one" \
"ADDSWAP" "Set up your swap partition(s)" \
"TARGET" "Set up your target partitions" \
-"INSTALL" "Install Slackware Live to disk" \
+"INSTALL" "Install @CDISTRO@ Live to disk" \
"CONFIGURE" "Reconfigure your Linux system" \
-"EXIT" "Exit Slackware Linux Setup" 2> $TMP/hdset
+"EXIT" "Exit @CDISTRO@ Linux Setup" 2> $TMP/hdset
if [ ! $? = 0 ]; then
rm -f $TMP/hdset $TMP/SeT*
exit
@@ -191,7 +191,7 @@ Press ENTER to return to the main menu." 16 68
# Take all modules mounted in the Live OS, and install them in that order:
for LIVE_MOD_BASE in $(ls -rt --indicator-style=none /mnt/live/modules/) ; do
- # Do not install 0099-slackware_zzzconf-*.sxz:
+ # Do not install 0099-@DISTRO@_zzzconf-*.sxz:
if echo ${LIVE_MOD_BASE} |grep -q "zzzconf" ; then
continue
fi
@@ -200,7 +200,7 @@ Press ENTER to return to the main menu." 16 68
echo "XXX"
echo "$GAUGE"
echo ""
- echo "Processed ${NUM_MOD} of ${TOT_MODS} Slackware Live modules ($(( $SIZ_MOD/1024 )) of $(( $DU_MODS/1024 )) MB)\nProcessing ${LIVE_MOD_BASE} ..."
+ echo "Processed ${NUM_MOD} of ${TOT_MODS} @CDISTRO@ Live modules ($(( $SIZ_MOD/1024 )) of $(( $DU_MODS/1024 )) MB)\nProcessing ${LIVE_MOD_BASE} ..."
echo "XXX"
unsquashfs -f -dest $T_PX ${LIVE_MOD} 1>>$TMP/unsquash_output 2>>$TMP/unsquash_error
let NUM_MOD=NUM_MOD+1
@@ -208,12 +208,12 @@ Press ENTER to return to the main menu." 16 68
GAUGE=$(( (100 * ${SIZ_MOD})/${DU_MODS} ))
echo "$GAUGE"
done
- ) | dialog --title "INSTALLING SLACKWARE @LIVEDE@ LIVE TO DISK" --gauge \
- "\nProcessing ${TOT_MODS} Slackware Live modules..." 8 65
+ ) | dialog --title "INSTALLING @UDISTRO@ @LIVEDE@ LIVE TO DISK" --gauge \
+ "\nProcessing ${TOT_MODS} @CDISTRO@ Live modules..." 8 65
- # Re-use some of the custom configuration from 0099-slackware_zzzconf-*.sxz
+ # Re-use some of the custom configuration from 0099-@DISTRO@_zzzconf-*.sxz
# (some of these may not be present but the command will not fail):
- dialog --title "POST-INSTALL SLACKWARE @LIVEDE@ LIVE DATA" --infobox \
+ dialog --title "POST-INSTALL @UDISTRO@ @LIVEDE@ LIVE DATA" --infobox \
"\nCopying Live modifications to hard disk ..." 5 65
# Do not overwrite a custom keymap:
if [ ! -f $T_PX/etc/rc.d/rc.keymap ]; then
@@ -232,7 +232,7 @@ Press ENTER to return to the main menu." 16 68
cat << EOF > $TMP/tempmsg
- Slackware @LIVEDE@ Live Edition has been installed to your hard drive!
+ @CDISTRO@ @LIVEDE@ Live Edition has been installed to your hard drive!
We installed the ${ACT_MODS} active modules (out of ${TOT_MODS} available).
If present, the following files were copied from the Live OS to your harddisk:
/etc/profile.d/lang.sh
@@ -337,12 +337,12 @@ if [ -f ${T_PX}/etc/fstab ]; then
# (it should now be ejected):
dialog \
--clear \
- --title "Slackware Linux Setup is complete" "$@" \
+ --title "@CDISTRO@ Linux Setup is complete" "$@" \
--msgbox "\nPlease remove the installation disc.\n" 7 40
fi
# Offer to reboot or drop to shell:
dialog \
- --title "Slackware Linux Setup is complete" "$@" \
+ --title "@CDISTRO@ Linux Setup is complete" "$@" \
--yesno \
"\nWould you like to reboot your system?\n\n\n\
If you choose \"No\", you will be dropped to a shell.\n" 11 50
diff --git a/make_slackware_live.sh b/make_slackware_live.sh
index e3aa6d0..837350a 100755
--- a/make_slackware_live.sh
+++ b/make_slackware_live.sh
@@ -133,10 +133,10 @@ SL_REPO=${SL_REPO:-"/mnt/auto/sox/ftp/pub/Linux/Slackware"}
DEF_SL_REPO=${SL_REPO}
# Package root directory:
-SL_PKGROOT=${SL_REPO}/slackware${DIRSUFFIX}-${SL_VERSION}/slackware${DIRSUFFIX}
+SL_PKGROOT=${SL_REPO}/${DISTRO}${DIRSUFFIX}-${SL_VERSION}/${DISTRO}${DIRSUFFIX}
DEF_SL_PKGROOT=${SL_PKGROOT}
# Patches root directory:
-SL_PATCHROOT=${SL_REPO}/slackware${DIRSUFFIX}-${SL_VERSION}/patches/packages
+SL_PATCHROOT=${SL_REPO}/${DISTRO}${DIRSUFFIX}-${SL_VERSION}/patches/packages
DEF_SL_PATCHROOT=${SL_PATCHROOT}
# List of Slackware package series - each will become a squashfs module:
@@ -304,7 +304,7 @@ function install_pkgs() {
fi
for PKG in $(cat ${PKGFILE} |grep -v -E '^ *#|^$' |cut -d: -f1); do
# Look in ./patches ; then ./slackware$DIRSUFFIX ; then ./extra
# Need to escape any '+' in package names such a 'gtk+2':
if [ ! -z "${SL_PATCHROOT}" ]; then
FULLPKG=$(full_pkgname ${PKG} ${SL_PATCHROOT})
@@ -372,6 +372,9 @@ function gen_bootmenu() {
-e "s/@LANG@/us/g" \
-e "s/@CONSFONT@/$CONSFONT/g" \
-e "s/@DIRSUFFIX@/$DIRSUFFIX/g" \
+ -e "s/@DISTRO@/$DISTRO/g" \
+ -e "s/@CDISTRO@/${DISTRO^}/g" \
+ -e "s/@UDISTRO@/${DISTRO^^}/g" \
-e "s/@KVER@/$KVER/g" \
-e "s/@LIVEMAIN@/$LIVEMAIN/g" \
-e "s/@MEDIALABEL@/$MEDIALABEL/g" \
@@ -404,6 +407,9 @@ EOL
-e "s/@LANG@/$LANCOD/g" \
-e "s/@CONSFONT@/$CONSFONT/g" \
-e "s/@DIRSUFFIX@/$DIRSUFFIX/g" \
+ -e "s/@DISTRO@/$DISTRO/g" \
+ -e "s/@CDISTRO@/${DISTRO^}/g" \
+ -e "s/@UDISTRO@/${DISTRO^^}/g" \
-e "s/@KVER@/$KVER/g" \
-e "s/@LIVEMAIN@/$LIVEMAIN/g" \
-e "s/@MEDIALABEL@/$MEDIALABEL/g" \
@@ -454,6 +460,9 @@ function gen_uefimenu() {
-e "s/@LANG@/us/g" \
-e "s/@CONSFONT@/$CONSFONT/g" \
-e "s/@DIRSUFFIX@/$DIRSUFFIX/g" \
+ -e "s/@DISTRO@/$DISTRO/g" \
+ -e "s/@CDISTRO@/${DISTRO^}/g" \
+ -e "s/@UDISTRO@/${DISTRO^^}/g" \
-e "s/@KVER@/$KVER/g" \
-e "s/@LIVEMAIN@/$LIVEMAIN/g" \
-e "s/@MEDIALABEL@/$MEDIALABEL/g" \
@@ -1062,6 +1071,9 @@ if [ -f ${LIVE_ROOTDIR}/boot/vmlinuz-huge-* ]; then
mkdir -p ${LIVE_ROOTDIR}/usr/local/sbin
cat ${LIVE_TOOLDIR}/setup2hd | sed \
-e "s/@DIRSUFFIX@/$DIRSUFFIX/g" \
+ -e "s/@DISTRO@/$DISTRO/g" \
+ -e "s/@CDISTRO@/${DISTRO^}/g" \
+ -e "s/@UDISTRO@/${DISTRO^^}/g" \
-e "s/@KVER@/$KVER/g" \
-e "s/@LIVEDE@/$LIVEDE/g" \
-e "s/@LIVEMAIN@/$LIVEMAIN/g" \
@@ -1583,6 +1595,9 @@ for SLFILE in message.txt f2.txt syslinux.cfg lang.cfg ; do
if [ -f ${LIVE_STAGING}/boot/syslinux/${SLFILE} ]; then
sed -i ${LIVE_STAGING}/boot/syslinux/${SLFILE} \
-e "s/@DIRSUFFIX@/$DIRSUFFIX/g" \
+ -e "s/@DISTRO@/$DISTRO/g" \
+ -e "s/@CDISTRO@/${DISTRO^}/g" \
+ -e "s/@UDISTRO@/${DISTRO^^}/g" \
-e "s/@KVER@/$KVER/g" \
-e "s/@LIVEMAIN@/$LIVEMAIN/g" \
-e "s/@MEDIALABEL@/$MEDIALABEL/g" \
@@ -304,7 +304,7 @@ function install_pkgs() {
fi
for PKG in $(cat ${PKGFILE} |grep -v -E '^ *#|^$' |cut -d: -f1); do
- # Look in ./patches ; then ./slackware$DIRSUFFIX ; then ./extra
+ # Look in ./patches ; then ./${DISTRO}$DIRSUFFIX ; then ./extra
# Need to escape any '+' in package names such a 'gtk+2':
if [ ! -z "${SL_PATCHROOT}" ]; then